@@ -65,7 +65,6 @@ struct MenuLayoutNodeRoot
   char *name;
 
   GSList *monitors;
-  guint   monitors_idle_handler;
 };
 
 struct MenuLayoutNodeMenu
@@ -134,14 +133,16 @@ node_next (MenuLayoutNode *node)
   return node->next;
 }
 
-static gboolean
-menu_layout_invoke_monitors (MenuLayoutNodeRoot *nr)
+static void
+handle_entry_directory_changed (EntryDirectory *dir,
+                                MenuLayoutNode *node)
 {
-  GSList *tmp;
+  MenuLayoutNodeRoot *nr;
+  GSList             *tmp;
 
-  g_assert (nr->node.type == MENU_LAYOUT_NODE_ROOT);
+  g_assert (node->type == MENU_LAYOUT_NODE_MENU);
 
-  nr->monitors_idle_handler = 0;
+  nr = (MenuLayoutNodeRoot *) menu_layout_node_get_root (node);
 
   tmp = nr->monitors;
   while (tmp != NULL)
@@ -153,24 +154,6 @@ menu_layout_invoke_monitors (MenuLayoutNodeRoot *nr)
 
       tmp = next;
     }
-
-  return FALSE;
-}
-
-static void
-handle_entry_directory_changed (EntryDirectory *dir,
-                                MenuLayoutNode *node)
-{
-  MenuLayoutNodeRoot *nr;
-
-  g_assert (node->type == MENU_LAYOUT_NODE_MENU);
-
-  nr = (MenuLayoutNodeRoot *) menu_layout_node_get_root (node);
-
-  if (nr->monitors_idle_handler == 0)
-    {
-      nr->monitors_idle_handler = g_idle_add ((GSourceFunc) menu_layout_invoke_monitors, nr);
-    }
 }
 
 static void
@@ -241,10 +224,6 @@ menu_layout_node_unref (MenuLayoutNode *node)
           g_slist_foreach (nr->monitors, (GFunc) g_free, NULL);
           g_slist_free (nr->monitors);
 
-          if (nr->monitors_idle_handler != 0)
-            g_source_remove (nr->monitors_idle_handler);
-          nr->monitors_idle_handler = 0;
-
           g_free (nr->basedir);
           g_free (nr->name);
         }
@@ -1783,162 +1762,6 @@ start_element_handler (GMarkupParseContext   *context,
   add_context_to_error (error, context);
 }
 
-/* we want to make sure that the <Layout> or <DefaultLayout> is either empty,
- * or contain one <Merge> of type "all", or contain one <Merge> of type "menus"
- * and one <Merge> of type "files". If this is not the case, we try to clean up
- * things:
- *  + if there is at least one <Merge> of type "all", then we only keep the
- *    last <Merge> of type "all" and remove all others <Merge>
- *  + if there is no <Merge> with type "all", we keep only the last <Merge> of
- *    type "menus" and the last <Merge> of type "files". If there's no <Merge>
- *    of type "menus" we append one, and then if there's no <Merge> of type
- *    "files", we append one. (So menus are before files)
- */
-static gboolean
-fixup_layout_node (GMarkupParseContext   *context,
-                   MenuParser            *parser,
-                   MenuLayoutNode        *node,
-                   GError              **error)
-{
-  MenuLayoutNode *child;
-  MenuLayoutNode *last_all;
-  MenuLayoutNode *last_menus;
-  MenuLayoutNode *last_files;
-  int             n_all;
-  int             n_menus;
-  int             n_files;
-
-  if (!node->children)
-    {
-      return TRUE;
-    }
-
-  last_all   = NULL;
-  last_menus = NULL;
-  last_files = NULL;
-  n_all   = 0;
-  n_menus = 0;
-  n_files = 0;
-
-  child = node->children;
-  while (child != NULL)
-    {
-      switch (child->type)
-        {
-        case MENU_LAYOUT_NODE_MERGE:
-	  switch (menu_layout_node_merge_get_type (child))
-	    {
-	    case MENU_LAYOUT_MERGE_NONE:
-	      break;
-
-	    case MENU_LAYOUT_MERGE_MENUS:
-	      last_menus = child;
-	      n_menus++;
-	      break;
-
-	    case MENU_LAYOUT_MERGE_FILES:
-	      last_files = child;
-	      n_files++;
-	      break;
-
-	    case MENU_LAYOUT_MERGE_ALL:
-	      last_all = child;
-	      n_all++;
-	      break;
-
-	    default:
-	      g_assert_not_reached ();
-	      break;
-	    }
-          break;
-
-	  default:
-	    break;
-	}
-
-      child = node_next (child);
-    }
-
-  if ((n_all == 1 && n_menus == 0 && n_files == 0) ||
-      (n_all == 0 && n_menus == 1 && n_files == 1))
-    {
-      return TRUE;
-    }
-  else if (n_all > 1 || n_menus > 1 || n_files > 1 ||
-           (n_all == 1 && (n_menus != 0 || n_files != 0)))
-    {
-      child = node->children;
-      while (child != NULL)
-	{
-	  MenuLayoutNode *next;
-
-	  next = node_next (child);
-
-	  switch (child->type)
-	    {
-	    case MENU_LAYOUT_NODE_MERGE:
-	      switch (menu_layout_node_merge_get_type (child))
-		{
-		case MENU_LAYOUT_MERGE_NONE:
-		  break;
-
-		case MENU_LAYOUT_MERGE_MENUS:
-		  if (n_all || last_menus != child)
-		    {
-		      menu_verbose ("removing duplicated merge menus element\n");
-		      menu_layout_node_unlink (child);
-		    }
-		  break;
-
-		case MENU_LAYOUT_MERGE_FILES:
-		  if (n_all || last_files != child)
-		    {
-		      menu_verbose ("removing duplicated merge files element\n");
-		      menu_layout_node_unlink (child);
-		    }
-		  break;
-
-		case MENU_LAYOUT_MERGE_ALL:
-		  if (last_all != child)
-		    {
-		      menu_verbose ("removing duplicated merge all element\n");
-		      menu_layout_node_unlink (child);
-		    }
-		  break;
-
-		default:
-		  g_assert_not_reached ();
-		  break;
-		}
-	      break;
-
-	      default:
-		break;
-	    }
-
-	  child = next;
-	}
-    }
-
-  if (n_all == 0 && n_menus == 0)
-    {
-      last_menus = menu_layout_node_new (MENU_LAYOUT_NODE_MERGE);
-      menu_layout_node_merge_set_type (last_menus, "menus");
-      menu_verbose ("appending missing merge menus element\n");
-      menu_layout_node_append_child (node, last_menus);
-    }
-
-  if (n_all == 0 && n_files == 0)
-    {
-      last_files = menu_layout_node_new (MENU_LAYOUT_NODE_MERGE);
-      menu_layout_node_merge_set_type (last_files, "files");
-      menu_verbose ("appending missing merge files element\n");
-      menu_layout_node_append_child (node, last_files);
-    }
-
-  return TRUE;
-}
-
 /* we want to a) check that we have old-new pairs and b) canonicalize
  * such that each <Move> has exactly one old-new pair
  */
@@ -2142,17 +1965,13 @@ end_element_handler (GMarkupParseContext  *context,
     case MENU_LAYOUT_NODE_KDE_LEGACY_DIRS:
     case MENU_LAYOUT_NODE_DELETED:
     case MENU_LAYOUT_NODE_NOT_DELETED:
+    case MENU_LAYOUT_NODE_LAYOUT:
+    case MENU_LAYOUT_NODE_DEFAULT_LAYOUT:
     case MENU_LAYOUT_NODE_SEPARATOR:
     case MENU_LAYOUT_NODE_MERGE:
     case MENU_LAYOUT_NODE_MERGE_FILE:
       break;
 
-    case MENU_LAYOUT_NODE_LAYOUT:
-    case MENU_LAYOUT_NODE_DEFAULT_LAYOUT:
-      if (!fixup_layout_node (context, parser, parser->stack_top, error))
-        goto out;
-      break;
-
     case MENU_LAYOUT_NODE_MOVE:
       if (!fixup_move_node (context, parser, parser->stack_top, error))
         goto out;
@@ -2284,7 +2103,6 @@ menu_parser_free (MenuParser *parser)
 
 MenuLayoutNode *
 menu_layout_load (const char  *filename,
-                  const char  *non_prefixed_basename,
                   GError     **err)
 {
   GMarkupParseContext *context;
@@ -2323,10 +2141,7 @@ menu_layout_load (const char  *filename,
   root->basedir = g_path_get_dirname (filename);
   menu_verbose ("Set basedir \"%s\"\n", root->basedir);
 
-  if (non_prefixed_basename)
-    s = g_strdup (non_prefixed_basename);
-  else
-    s = g_path_get_basename (filename);
+  s = g_path_get_basename (filename);
   str = g_string_new (s);
   if (g_str_has_suffix (str->str, ".menu"))
     g_string_truncate (str, str->len - strlen (".menu"));
